# SINGA-Easy

![Lint](https://github.com/nusdbsystem/singa-easy/workflows/Lint/badge.svg?branch=master&event=push)


This repository includes a set of plugins (e.g., models and web UI) for [SINGA-Auto](https://github.com/nusdbsystem/singa-auto/).

# Scripts
1. To start the application, use this script: bash ./scripts/start.sh
2. To stop the application, use this script: bash ./scripts/stop.sh